@@ -10,36 +10,23 @@ import numpy as np
 import scipy.sparse
 from copy import copy
 
+from list_utils import *
+
 one = np.array(1) # a surprisingly useful little array; makes lists into arrays by simply one*[[1,2],[3,6],...]
 
-def flatten(l):
-    '''A wrapper around the generator-based list flattener (quite fast)'''
-    return [j for i in l for j in i]
-def zipflat(*args):
-    '''Like zip, but flattens the result'''
-    return [j for i in zip(*args) for j in i]
-def totuple(a):
-    '''Makes tuples out of nested datastructures like lists and arrays.
-       Authored by Bi Rico, http://stackoverflow.com/questions/10016352/convert-numpy-array-to-tuple'''
-    try:
-        return tuple(totuple(i) for i in a)
-    except TypeError: # dig until we can dig no more!
-        return a
-def makeTuple(a):
-    '''Like totuple, but ensures that you get a tuple out.'''
-    retVal = totuple(a)
-    return ( retVal if retVal.__class__==tuple else (retVal,) )
-def removeDuplicates(l):
-    '''Order preserving duplicate removal... automatically converts lists and arrays (which are unhashable) to nested tuples.
-       Modified version of code found here: http://stackoverflow.com/questions/480214/how-do-you-remove-duplicates-from-a-list-in-python-whilst-preserving-order'''
-    seen = set()
-    return [ x for x in totuple(l) if x not in seen and not seen.add(x)]
 def limitInteriorPoints(l,numInteriorPoints,uniqueOnly=True):
-    '''return the list l with only the endpoints and a few interior points (WILL DUPLICATE IF TOO FEW POINTS)'''
+    '''return the list l with only the endpoints and a few interior points (uniqueOnly will duplicate if too few points)'''
     inds = np.linspace(0,len(l)-1,numInteriorPoints+2).round().astype(np.integer)
     if uniqueOnly:
         inds = np.unique(inds)
     return [ l[i] for i in inds ]
+
+def partitionNumpy(l,n):
+    '''Like partition, but always clips and returns array, not list'''
+    a=np.array(l)
+    a.resize(len(l)//n,n)
+    return a
+
 def shape_multiply(arr,shapeMultiplier, oddOnly=False, adjustFunction=None):
     '''Works like tile except that it keeps all like elements clumped\n'''
     '''Essentially a non-interpolating multi-dimensional image up-scaler'''
@@ -268,6 +255,3 @@ def blitSphereToArray(arr,x,y,z,r,val):
     #print arr[xL:xH,yL:yH].shape,c.shape
     arr[xL:xH,yL:yH,zL:zH] *= (1-c)
     arr[xL:xH,yL:yH,zL:zH] += (val*c)
-
-circs = [ImageCircle(i) for i in range(1,100)]
-shprs = [ImageSphere(i) for i in range(1,20)]
